Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(165)

Unified Diff: third_party/WebKit/Source/core/layout/svg/LayoutSVGInline.h

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/svg/LayoutSVGInline.h
diff --git a/third_party/WebKit/Source/core/layout/svg/LayoutSVGInline.h b/third_party/WebKit/Source/core/layout/svg/LayoutSVGInline.h
index 43e615f938b49e75c36bb0cfe195a357452342ad..e07ec0f00c8375e799629c44a64675e6faf29dc2 100644
--- a/third_party/WebKit/Source/core/layout/svg/LayoutSVGInline.h
+++ b/third_party/WebKit/Source/core/layout/svg/LayoutSVGInline.h
@@ -41,13 +41,13 @@ class LayoutSVGInline : public LayoutInline {
// Chapter 10.4 of the SVG Specification say that we should use the
// object bounding box of the parent text element.
// We search for the root text element and take its bounding box.
// It is also necessary to take the stroke and paint invalidation rect of
// this element, since we need it for filters.
FloatRect objectBoundingBox() const final;
FloatRect strokeBoundingBox() const final;
- FloatRect paintInvalidationRectInLocalSVGCoordinates() const final;
+ FloatRect visualRectInLocalSVGCoordinates() const final;
- LayoutRect absoluteClippedOverflowRect() const final;
+ LayoutRect absoluteVisualRect() const final;
void mapLocalToAncestor(const LayoutBoxModelObject* ancestor,
TransformState&,
MapCoordinatesFlags = ApplyContainerFlip) const final;
@@ -41,13 +41,13 @@ class LayoutSVGInline : public LayoutInline {
// object bounding box of the parent text element.
// We search for the root text element and take its bounding box.
- // It is also necessary to take the stroke and paint invalidation rect of
- // this element, since we need it for filters.
+ // It is also necessary to take the stroke and visual rect of this element,
+ // since we need it for filters.
FloatRect objectBoundingBox() const final;
FloatRect strokeBoundingBox() const final;

Powered by Google App Engine
This is Rietveld 408576698